/*
 * A resource supporting the creation of user-specific ext2 filesystem opener
 * resources.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <ext2fs/ext2fs.h>

#include <fsserver/ext2_file_operations.h>
#include <fsserver/filesystem_resource.h>



/* Support for providing access to user-specific filesystems. */

class Ext2Filesystem : public FilesystemResource
{
protected:
    Ext2FileOperations *_ops;

public:
    explicit Ext2Filesystem(Pages *pages, ext2_filsys fs);

    virtual ~Ext2Filesystem();

    /* Filesystem interface methods. */

    virtual long open_for_user(ipc_varg_sys_uid_t uid, ipc_varg_sys_gid_t gid,
                               ipc_varg_sys_mode_t umask, l4_cap_idx_t *opener);

    virtual long open_for_user(user_t user, l4_cap_idx_t *opener);
};

// vim: tabstop=4 expandtab shiftwidth=4
